MotionColors class

Curated color palette for each preset.

Constructors

MotionColors({required Color primary, required Color secondary, required Color accent, required Color surface, required Color surfaceVariant, required Color background, required Color foreground, required Color mutedForeground, required Color border, required Color borderSubtle, required Color shadow, required Color success, required Color error, required Color warning})
const

Properties

accent Color
final
background Color
final
border Color
final
borderSubtle Color
final
error Color
final
foreground Color
final
hashCode int
The hash code for this object.
no setterinherited
mutedForeground Color
final
primary Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
final
shadow Color
final
success Color
final
surface Color
final
surfaceVariant Color
final
warning Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

aurora({bool dark = false}) MotionColors
Aurora preset palette (vibrant gradients).
elegant({bool dark = false}) MotionColors
Elegant/Luxury preset palette (gold, rich).
glass({bool dark = false}) MotionColors
Glass preset palette (translucent, frosted).
minimal({bool dark = false}) MotionColors
Minimal preset palette (clean, flat, premium).
modern({bool dark = false}) MotionColors
Modern/Neo preset palette (bold, sharp).