MotionShadows class
Layered shadow presets that create depth like Apple/Linear/Stripe.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
glow(
Color color, {double intensity = 0.4}) → List< BoxShadow> - Colored glow shadow.
-
hard(
Color color, {double offset = 4}) → List< BoxShadow> - Neo-brutalist hard offset shadow.
-
medium(
Color color) → List< BoxShadow> - Medium elevation (cards on hover).
-
strong(
Color color) → List< BoxShadow> - Strong elevation (floating elements, modals).
-
subtle(
Color color) → List< BoxShadow> - Subtle elevation (cards at rest).